msg_dict = {1: {'msg1':"Clique SIM para fazer busca das fotos ou NÃO para sair!",
                    'msg2':"Selecione o diretorio das fotos!!:",
                    'msg3':"Clique SIM para escolher onde GRAVAR album ou NÃO para sair!",
                    'msg4':"Selecione o diretorio para Gravação!!",
                    'msg5':"Você escolheu SAIR !",
                    'msg6':"Encerrando ...!!!",
                    'msg7':"Numero de fotos insuficiente !!!!\n",
                    'msg8':"Voce possui ",
                    'msg9':" fotos !!!!\n",
                    'msg10':"Aguarde gerando pagina do album ...!",
                    'msg11':"Rotina retornou um ERRO!!!",
                    'msg12':"Album de fotografias_",
                    'msg13':"Idiomas disponiveis:"}, 
                #messages in english    
                2: {'msg1':"Click YES to search the photos or NO to exit!",
                    'msg2':"Select the photo directory!!:",
                    'msg3':"Click YES to choose where to RECORD album or NO to exit!",
                    'msg4':"Select the directory for Recording!!",
                    'msg5':"You have chosen EXIT !",
                    'msg6':"Closing...!!!",
                    'msg7':"Insufficient number of photos !!!!\n",
                    'msg8':"You own ",
                    'msg9':" pictures !!!!\n",
                    'msg10':"Please wait, generating album page...!",
                    'msg11':"Routine returned an ERROR!!!",
                    'msg12':"Photo album_",
                    'msg13':"Languages availables: "}
                }
 